@@ -11,17 +11,18 @@ from egse.log import logger
 from egse.scpi import AsyncSCPIInterface
 from egse.settings import Settings
 
-settings = Settings.load("Keithley DAQ6510")
+dev_settings = Settings.load("Keithley DAQ6510")
 
-DAQ_DEV_PORT = settings.get("PORT")
-DAQ_DEV_NAME = "DAQ6510"
-DAQ_DEV_ID_VALIDATION = "DAQ6510"
+DEV_HOST = dev_settings.get("HOSTNAME")
+DEV_PORT = dev_settings.get("PORT")
+DEVICE_NAME = dev_settings.get("DEVICE_NAME", "DAQ6510")
+DEV_ID_VALIDATION = "DAQ6510"
 
 
 class DAQ6510(AsyncSCPIInterface):
     """Keithley DAQ6510 specific implementation."""
 
-    def __init__(self, hostname: str, port: int = DAQ_DEV_PORT, settings: Optional[Dict[str, Any]] = None):
+    def __init__(self, hostname: str = DEV_HOST, port: int = DEV_PORT, settings: Optional[Dict[str, Any]] = None):
         """Initialize a Keithley DAQ6510 interface.
 
         Args:
@@ -30,11 +31,11 @@ class DAQ6510(AsyncSCPIInterface):
             settings: Additional device settings
         """
         super().__init__(
-            device_name=DAQ_DEV_NAME,
+            device_name=DEVICE_NAME,
             hostname=hostname,
             port=port,
             settings=settings,
-            id_validation=DAQ_DEV_ID_VALIDATION,  # String that must appear in IDN? response
+            id_validation=DEV_ID_VALIDATION,  # String that must appear in IDN? response
         )
 
         self._measurement_lock = asyncio.Lock()
